;; Generated package description from compat.el  -*- no-byte-compile: t -*-
(define-package "compat" "30.0.2.0" "Emacs Lisp Compatibility Library" '((emacs "24.4") (seq "2.23")) :commit "e87b984bf763aa6c574dde58b3cb4458b3b7db17" :authors '(("Philip Kaludercic" . "philipk@posteo.net") ("Daniel Mendler" . "mail@daniel-mendler.de")) :maintainer '("Compat Development" . "~pkal/compat-devel@lists.sr.ht") :keywords '("lisp" "maint") :url "https://github.com/emacs-compat/compat")
